@@ -1,12 +1,10 @@
 """Descriptor of an entity field."""
 
-import operator
 from datetime import date, datetime
-from typing import Any, AnyStr, Optional, Tuple, Type, Union
+from typing import Any, AnyStr, Iterable, Optional, Tuple, Type, Union
 
 from dateutil.parser import parse
 
-from pydbrepo.entity.entity import Entity
 from pydbrepo.entity.enum_entity import EnumEntity
 from pydbrepo.errors import FieldCastError, FieldTypeError
 
@@ -18,9 +16,8 @@ class Field:
 
     :param type_: Python type of the field
     :param cast_to: Class that describes the type that the field should be casted to
+    :param cast_items_to: Class that will be used to cast all items on Iterable object
     :param cast_if: Class that describes the type that the field should be casted to if it is equal to the given value
-    :param value: Initial default field value
-    :param name: Field name
     """
 
     def __init__(
@@ -28,75 +25,32 @@ class Field:
         type_: Union[Type, Tuple],
         cast_to: Optional[Type] = None,
         cast_if: Optional[Union[Type, Tuple[Type, ...]]] = None,
-        name: Optional[AnyStr] = None,
-        value: Optional[Any] = None
+        cast_items_to: Optional[Type] = None,
+        field: Optional[AnyStr] = None,
     ):
-        self._value = value
         self._type = type_
         self._cast_to = cast_to
+        self._cast_items_to = cast_items_to
         self._cast_if = cast_if
-        self._name = name
+        self.field = field
 
     def __set__(self, instance, value):
         """Validate and save field value."""
 
         self._validate_types(instance, value)
-        self._value = self._cast_value(instance, value)
+        value = self._cast_value(instance, value)
 
-    def __get__(self, instance, owner) -> Any:
+        instance.__dict__[self.field] = value
+
+    def __get__(self, instance, owner_type) -> Any:
         """Return saved field value."""
 
-        if issubclass(type(self._value), EnumEntity):
-            return self._value.value
+        field = instance.__dict__.get(self.field, None)
 
-        return self._value
+        if issubclass(type(field), EnumEntity):
+            return field.value
 
-    def __lt__(self, other: Any) -> bool:
-        """Lower than comparison."""
-        return operator.__lt__(self._value, other)
-
-    def __le__(self, other: Any) -> bool:
-        """Lower or equal comparison."""
-        return operator.__le__(self._value, other)
-
-    def __gt__(self, other: Any) -> bool:
-        """Grater than comparison."""
-        return operator.__gt__(self._value, other)
-
-    def __ge__(self, other: Any) -> bool:
-        """Grater or equal comparison"""
-        return operator.__ge__(self._value, other)
-
-    def __eq__(self, other: Any) -> bool:
-        """Equals to comparison."""
-        return operator.__eq__(self._value, other)
-
-    def __ne__(self, other) -> bool:
-        """Different of comparison."""
-        return operator.__ne__(self._value, other)
-
-    def __neg__(self):
-        """Negation operation"""
-
-        return operator.__neg__(self._value)
-
-    def __add__(self, other: Any) -> Any:
-        return operator.__add__(self._value, other)
-
-    def __sub__(self, other: Any) -> Any:
-        return operator.__sub__(self._value, other)
-
-    def __mul__(self, other: Any) -> Any:
-        return operator.__mul__(self._value, other)
-
-    def __divmod__(self, other: Any) -> Any:
-        return operator.__mod__(self._value, other)
-
-    def __truediv__(self, other: Any) -> Any:
-        return operator.__truediv__(self._value, other)
-
-    def __floordiv__(self, other: Any) -> Any:
-        return operator.__floordiv__(self._value, other)
+        return field
 
     def _validate_types(self, instance: Any, value: Any):
         """Execute type validation for field value.
@@ -107,7 +61,7 @@ class Field:
         """
 
         if not isinstance(value, self._type) and value is not None:
-            raise FieldTypeError(instance.__class__.__name__, self._name, value, self._type)
+            raise FieldTypeError(instance.__class__.__name__, self.field, value, self._type)
 
     def _cast_value(self, instance: Any, value: Any) -> Any:
         """Execute cast over given value to convert it into an instance of a specific class.
@@ -117,51 +71,90 @@ class Field:
         :return Any: Casted value
         """
 
-        if self._cast_to is None or isinstance(value, self._cast_to) or value is None:
+        if self._cast_items_to:
+            return self._cast_iterable(instance, value)
+
+        if self._cast_to:
+            return self._cast_non_iterables(instance, value)
+
+        return value
+
+    def _cast_non_iterables(self, instance: Any, value: Any) -> Any:
+        """Cast non iterable object values.
+
+        :param instance: Filed owner class
+        :param value: Un-casted value
+        :return Any: Casted value
+        """
+
+        if isinstance(value, self._cast_to) or value is None:
             return value
 
         if self._cast_if is not None:
             if isinstance(value, self._cast_if):
-                return self._handle_cast(instance, value)
+                return self._handle_cast(self._cast_to, instance, value)
 
             raise FieldCastError(
                 class_name=instance.__class__.__name__,
-                field=self._name,
+                field=self.field,
                 value=value,
                 cast_to=self._cast_to,
                 current_type=type(value),
                 cast_if=self._cast_if
             )
 
-        return self._handle_cast(instance, value)
+        return self._handle_cast(self._cast_to, instance, value)
 
-    def _handle_cast(self, instance: Any, value: Any) -> Any:
+    def _cast_iterable(self, instance: Any, value: Iterable) -> Any:
+        """Cast iterable object items.
+
+        :param instance: Filed owner class
+        :param value: Un-casted value
+        :return Any: Casted value
+        """
+
+        if self._cast_items_to is None or not value:
+            return value
+
+        items = []
+
+        for item in value:
+            if isinstance(item, self._cast_items_to):
+                items.append(item)
+
+            item = self._handle_cast(self._cast_items_to, instance, item)
+
+            items.append(item)
+
+        return type(value)(items)
+
+    def _handle_cast(self, cast_to: Type, instance: Any, value: Any) -> Any:
         """Return casted value
 
+        :param cast_to: Type to be casted
         :param value: Un-casted value
         :return Any: New instance of the value with the corresponding type
         """
 
         try:
             # Cast for string dates
-            if self._cast_to in {date, datetime}:
+            if cast_to == datetime:
                 return parse(value)
 
-            if issubclass(self._cast_to, Entity):
-                return self._cast_to.from_dict(value)
+            if cast_to == date:
+                return parse(value).date()
+
+            if 'from_dict' in set(dir(cast_to)):
+                return cast_to().from_dict(value)
 
             return self._cast_to(value)
         except Exception as error:
             raise FieldCastError(
                 class_name=instance.__class__.__name__,
-                field=self._name,
+                field=self.field,
                 value=value,
-                cast_to=self._cast_to,
+                cast_to=cast_to,
                 cast_if=self._cast_if,
                 current_type=type(value),
                 errors=error
             )
-
-    def __repr__(self):
-        """Field representation."""
-        return self._value.__repr__()
